pub trait SelectSettings<P: Sub>where
P::Output: InnerSpace,{
// Required method
fn grab_distance(&self) -> <P::Output as VectorSpace>::Scalar;
// Provided methods
fn connect(&mut self, _points: &[P], _index: usize, _selected: &[usize]) { ... }
fn special(&mut self, _points: &[P], _index: usize, _selected: &[usize]) { ... }
}Expand description
A trait for configuring selection settings for point objects.
The SelectSettings trait is generic over the point type P.
Required Methods
Sourcefn grab_distance(&self) -> <P::Output as VectorSpace>::Scalar
fn grab_distance(&self) -> <P::Output as VectorSpace>::Scalar
Returns the grab distance for selecting points.
Returns
The grab distance as the scalar type of the point’s vector space.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".